api.system.notification.v1 package — Argus-Toolbelt 1.0 documentation

# api.system.notification.v1 package

## Submodules

## api.system.notification.v1.events module

Autogenerated API

`api.system.notification.v1.events.` `list_events`(json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List defined notification events (INTERNAL)

  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {}

## api.system.notification.v1.rule module

Autogenerated API

`api.system.notification.v1.rule.` `add_action`(id: int, index: int, changeMatching: str = None, changeTypes: <function list at 0x1129b4ae8> = None, changeFormats: <function list at 0x1129b4ae8> = None, changeRoles: <function list at 0x1129b4ae8> = None, sender: str = None, setFlags: int = None, unsetFlags: int = None, subjectTemplate: dict = None, bodyTemplate: dict = None, smsTemplate: dict = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add notification action to rule (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of rule to add this action to index (int) – Index to put this action at changeMatching (str) – [sw{}$-().[]“‘_/,*+#:@!?;]* changeTypes (list) – changeFormats (list) – changeRoles (list) – sender (str) – setFlags (int) – unsetFlags (int) – subjectTemplate (dict) – format:html bodyTemplate (dict) – format:html smsTemplate (dict) – [sw{}$-().[]“‘_/,*+#:@!?;]*
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 902, “limit”: 347, “responseCode”: 200, “count”: 555, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Participant best defense crime run.”, “messageTemplate”: “Though night fear region eight event.”, “field”: “Report popular seek policy hand stock themselves.”, “parameter”: {}, “timestamp”: 55564098}], “currentPage”: 80, “size”: 13}

`api.system.notification.v1.rule.` `add_destination`(id: int, format: str = None, type: str = None, role: str = None, name: str = None, destination: str = None, language: str = None, flags: int = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add destination to notification rule (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of rule to add this destination to format (str) – type (str) – role (str) – name (str) – [sw{}$-().[]“‘_/,*+#:@!?;]* destination (str) – language (str) – flags (int) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 944, “limit”: 584, “responseCode”: 200, “count”: 138, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Into policy share act foreign region agree.”, “messageTemplate”: “For happy market campaign coach.”, “field”: “Interesting real decide late toward with I.”, “parameter”: {}, “timestamp”: 1190684668}], “currentPage”: 10, “size”: 411}

`api.system.notification.v1.rule.` `create`(name: str = None, matchRule: str = None, customerID: int = None, setFlags: int = None, actions: <function list at 0x1129b4ae8> = None, additionalDestinations: <function list at 0x1129b4ae8> = None, events: <function list at 0x1129b4ae8> = None, index: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add notification rule (INTERNAL)

  Return type: | `dict`
  Parameters: | name (str) – Notification rule name => [sw{}$-().[]“‘_/,*+#:@!?;]* matchRule (str) – customerID (int) – setFlags (int) – actions (list) – Actions additionalDestinations (list) – events (list) – index (int) – index (default 0)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 420, “limit”: 543, “responseCode”: 200, “count”: 994, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Model personal behavior manage see.”, “messageTemplate”: “Product staff must nothing.”, “field”: “Western west heart board.”, “parameter”: {}, “timestamp”: 184548869}], “currentPage”: 542, “size”: 768}

`api.system.notification.v1.rule.` `delete_action`(id: int, index: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete action from notification rule (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of rule index (int) – Index of action to delete
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 206, “limit”: 467, “responseCode”: 200, “count”: 126, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Measure year last special kid model.”, “messageTemplate”: “Data continue reality western kid.”, “field”: “Street shoulder so table.”, “parameter”: {}, “timestamp”: 586341039}], “currentPage”: 45, “size”: 469}

`api.system.notification.v1.rule.` `delete_destination`(id: int, index: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete destination from notification rule (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of rule index (int) – Index of destination to delete
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 95, “limit”: 851, “responseCode”: 200, “count”: 116, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “At agent unit company suggest nature.”, “messageTemplate”: “Hotel its language question child civil while.”, “field”: “Light again voice walk.”, “parameter”: {}, “timestamp”: 1431643938}], “currentPage”: 457, “size”: 912}

`api.system.notification.v1.rule.` `delete_rule`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete notification rule (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of rule to delete
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 925, “limit”: 32, “responseCode”: 200, “count”: 22, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Open task point certainly wait recently answer history.”, “messageTemplate”: “Color television then story short hour expert activity.”, “field”: “Sometimes campaign beat.”, “parameter”: {}, “timestamp”: 523034430}], “currentPage”: 547, “size”: 793}

`api.system.notification.v1.rule.` `duplicate_rule`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Duplicate this notification rule (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of rule to duplicate
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 515, “limit”: 493, “responseCode”: 200, “count”: 931, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Human wide owner hold claim tough.”, “messageTemplate”: “Choose follow manager several.”, “field”: “Sister both type south door travel hotel or.”, “parameter”: {}, “timestamp”: 1329019540}], “currentPage”: 663, “size”: 38}

`api.system.notification.v1.rule.` `get_rule_by_id`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch notification rule (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of rule to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 225, “limit”: 168, “responseCode”: 200, “count”: 755, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Day measure focus air when free imagine.”, “messageTemplate”: “Who north money every though.”, “field”: “Successful indeed serve respond increase.”, “parameter”: {}, “timestamp”: 846158952}], “currentPage”: 277, “size”: 619}

`api.system.notification.v1.rule.` `get_rule_by_name`(name: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch notification rule (INTERNAL)

  Return type: | `dict`
  Parameters: | name (str) – Name of rule to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 731, “limit”: 126, “responseCode”: 200, “count”: 187, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Require certainly bad rather.”, “messageTemplate”: “Call artist attention local.”, “field”: “Single authority future might beat in.”, “parameter”: {}, “timestamp”: 1056529161}], “currentPage”: 662, “size”: 484}

`api.system.notification.v1.rule.` `list`(includeDeleted: bool = None, includeFlags: int = None, excludeFlags: int = None, customerID: list = None, includeGlobal: bool = None, offset: int = None, events: list = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List notification rules (INTERNAL)

  Return type: | `dict`
  Parameters: | includeDeleted (bool) – Include deleted rules includeFlags (int) – Limit result to rules with these flagbits set excludeFlags (int) – Limit result to rules with these flagbits unset customerID (list) – Limit result to rules for these customers includeGlobal (bool) – Include global rules offset (int) – Offset result events (list) – Limit result to rules for these events limit (int) – Limit result
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 493, “limit”: 855, “responseCode”: 200, “count”: 157, “data”: [{“id”: 816, “revision”: 776, “name”: “Dale Vasquez”, “matchRule”: “Subject coach cover use.”, “index”: 625, “flags”: 878, “actions”: [{“changeMatching”: “Far around item international.”, “changeTypes”: [“SMS”], “changeFormats”: [“BRIEF”], “changeRoles”: [“CC”], “sender”: “Fund development on stand food.”, “setFlags”: 522, “unsetFlags”: 502, “subjectTemplate”: {“additionalProperties”: “Everybody window service issue law.”}, “bodyTemplate”: {“additionalProperties”: “Point note development word happy several sense candidate.”}, “smsTemplate”: {“additionalProperties”: “Marriage determine military need produce doctor.”}}], “additionalDestinations”: [{“role”: “REPORTER”, “name”: “Anna Maxwell”, “destination”: “Such able character partner.”, “language”: “ENGLISH”, “flags”: 929}], “timestamp”: 1220646578, “lastUpdatedTimestamp”: 563527190, “lastUpdatedByUser”: {“id”: 176, “customerID”: 699, “userName”: “nicholassexton”, “name”: “Crystal Baker”}, “events”: [“Lay toward may feeling floor cost certain.”], “globalCustomer”: false}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Sure kind cut central board Democrat whom.”, “messageTemplate”: “Stop break theory support work feel hair month.”, “field”: “Fall report partner on true book.”, “parameter”: {}, “timestamp”: 460088021}], “currentPage”: 932, “size”: 19}

`api.system.notification.v1.rule.` `revisions`(id: int, offset: int = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List revisions of notification rule (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of rule to fetch offset (int) – Offset result limit (int) – Limit result
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 482, “limit”: 708, “responseCode”: 200, “count”: 897, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Stay surface serious term.”, “messageTemplate”: “Maybe majority finally pretty environment.”, “field”: “Mean relate course thousand good.”, “parameter”: {}, “timestamp”: 99403013}], “currentPage”: 485, “size”: 415}

`api.system.notification.v1.rule.` `update_action`(id: int, changeMatching: str = None, changeTypes: <function list at 0x1129b4ae8> = None, changeFormats: <function list at 0x1129b4ae8> = None, changeRoles: <function list at 0x1129b4ae8> = None, sender: str = None, setFlags: int = None, unsetFlags: int = None, subjectTemplate: dict = None, bodyTemplate: dict = None, smsTemplate: dict = None, index: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update notification rule action (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of rule to update changeMatching (str) – [sw{}$-().[]“‘_/,*+#:@!?;]* changeTypes (list) – changeFormats (list) – changeRoles (list) – sender (str) – setFlags (int) – unsetFlags (int) – subjectTemplate (dict) – format:html bodyTemplate (dict) – format:html smsTemplate (dict) – [sw{}$-().[]“‘_/,*+#:@!?;]* index (int) – Index of action to update
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 621, “limit”: 374, “responseCode”: 200, “count”: 982, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Animal specific create management.”, “messageTemplate”: “Hundred free rest bit impact class black organization.”, “field”: “Throw act large simply rate your.”, “parameter”: {}, “timestamp”: 1204165275}], “currentPage”: 286, “size”: 480}

`api.system.notification.v1.rule.` `update_destination`(id: int, index: int, format: str = None, type: str = None, role: str = None, name: str = None, destination: str = None, language: str = None, flags: int = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update notification rule destination (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of rule to update index (int) – Index of destination to update format (str) – type (str) – role (str) – name (str) – [sw{}$-().[]“‘_/,*+#:@!?;]* destination (str) – language (str) – flags (int) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 211, “limit”: 135, “responseCode”: 200, “count”: 673, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Nor sometimes seek movement ground attorney.”, “messageTemplate”: “Son live course drug road box like.”, “field”: “Start room today soon bag.”, “parameter”: {}, “timestamp”: 1098214541}], “currentPage”: 977, “size”: 219}

`api.system.notification.v1.rule.` `update_rule`(id: int, name: str = None, matchRule: str = None, index: int = None, setFlags: int = None, unsetFlags: int = None, actions: <function list at 0x1129b4ae8> = None, additionalDestinations: <function list at 0x1129b4ae8> = None, events: <function list at 0x1129b4ae8> = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update notification rule (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of rule to update name (str) – [sw{}$-().[]“‘_/,*+#:@!?;]* matchRule (str) – index (int) – index (default null) setFlags (int) – unsetFlags (int) – actions (list) – additionalDestinations (list) – events (list) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 373, “limit”: 110, “responseCode”: 200, “count”: 214, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Across response entire mouth.”, “messageTemplate”: “Common reach individual them above.”, “field”: “Them benefit plant or best result game nor.”, “parameter”: {}, “timestamp”: 1171381760}], “currentPage”: 594, “size”: 829}

## Module contents